@@ -25,7 +25,4 @@
 
 #include "libevolvotron_precompiled.h"
 
-// Used for determining number of processors.
-#include <sched.h>
-
 #endif
