@@ -27,21 +27,24 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "evolvotron_main.h"
 
-/*! The constructor is passed:
-    - the owning widget (expected to be null but it might get used somewhere else one day)
-    - the EvolvotronMain providing spawn and farm services,
-    - the MutatableImageDisplay to be held
- */
-MutatableImageDisplayBig::MutatableImageDisplayBig(QWidget* parent,EvolvotronMain* mn)
-  :QWidget(parent,0,Qt::WDestructiveClose)
-   ,_main(mn)
-   ,_held(0)
-{}
+MutatableImageDisplayBig::MutatableImageDisplayBig(EvolvotronMain* mn)
+  :QWidget(mn,Qt::Window)  // We're a window, but with a parent
+  ,_main(mn)
+{
+  setAttribute(Qt::WA_DeleteOnClose,true);
+
+  setWindowTitle("Evolvotron");
+  setMinimumSize(256,256);
+  
+  //setSizeGripEnabled(true); // Only an option if we give the window a statusbar, or make it a dialog
+}
 
 /*! Don't think destructor needs to do anything to _display... Qt takes care of it
  */
 MutatableImageDisplayBig::~MutatableImageDisplayBig()
-{}
+{
+  std::clog << "An enlargement was deleted\n";
+}
 
 /*! There's not much point in dropping back to normal mode (from fullscreen) if the main
   app is fullscreen because we'll just be hidden, so close instead under such circumstances.
@@ -56,7 +59,7 @@ void MutatableImageDisplayBig::keyPressEvent(QKeyEvent* e)
       else
 	showNormal();  
     }
-  else if (e->key()==Qt::Key_F && !(e->state()^Qt::ControlButton))
+  else if (e->key()==Qt::Key_F && !e->modifiers())
     {
       if (isFullScreen())
 	{
@@ -73,8 +76,3 @@ void MutatableImageDisplayBig::keyPressEvent(QKeyEvent* e)
       e->ignore();
     }
 }
-
-void MutatableImageDisplayBig::resizeEvent(QResizeEvent*)
-{
-  _held->resize(size());
-}
